@@ -5,9 +5,10 @@
 #include "qtexttospeech_winrt.h"
 #include "qtexttospeech_winrt_audiosource.h"
 
-#include <QtMultimedia/QAudioSink>
-#include <QtMultimedia/QMediaDevices>
-#include <QtMultimedia/QAudioDevice>
+#include <QtMultimedia/qaudiodevice.h>
+#include <QtMultimedia/qaudiosink.h>
+#include <QtMultimedia/qmediadevices.h>
+#include <QtMultimedia/private/qaudiosystem_p.h>
 
 #include <QtCore/QBasicTimer>
 #include <QtCore/QCoreApplication>
@@ -339,6 +340,9 @@ bool QTextToSpeechEngineWinRT::setVoice(const QVoice &voice)
     d->forEachVoice([&data, &foundVoice](const ComPtr<IVoiceInformation> &voiceInfo) {
         HString voiceId;
         HRESULT hr = voiceInfo->get_Id(voiceId.GetAddressOf());
+        if (FAILED(hr))
+            return false;
+
         if (data == QString::fromWCharArray(voiceId.GetRawBuffer(0))) {
             foundVoice = voiceInfo;
             return true;
@@ -407,6 +411,11 @@ void QTextToSpeechEngineWinRTPrivate::initializeAudioSink(const QAudioFormat &fo
     currentBoundary = boundaries.constBegin();
 
     audioSink.reset(new QAudioSink(audioDevice, format));
+    // LATER: use public API (compare QTBUG-138378)
+    QPlatformAudioSink *platformAudioSink = QPlatformAudioSink::get(*audioSink);
+    if (platformAudioSink)
+        platformAudioSink->setRole(QPlatformAudioSink::AudioEndpointRole::Accessibility);
+
     QObject::connect(audioSink.get(), &QAudioSink::stateChanged,
                      q, [this](QAudio::State sinkState) {
         sinkStateChanged(sinkState);
